summaryrefslogtreecommitdiff
path: root/ftpfs
diff options
context:
space:
mode:
authorMiles Bader <miles@gnu.org>1997-08-18 18:51:05 +0000
committerMiles Bader <miles@gnu.org>1997-08-18 18:51:05 +0000
commitdd2c5b65620bd29498b562867fe40226fbb1893a (patch)
treebefb38020e3398581f035081deb7ade273530005 /ftpfs
parent8fc101c723708147f53b0e4480ac2f6e409b76b5 (diff)
(ftpfs_dir_null_lookup):
New declaration.
Diffstat (limited to 'ftpfs')
-rw-r--r--ftpfs/ftpfs.h13
1 files changed, 12 insertions, 1 deletions
diff --git a/ftpfs/ftpfs.h b/ftpfs/ftpfs.h
index e518d1f4..0ca67aa4 100644
--- a/ftpfs/ftpfs.h
+++ b/ftpfs/ftpfs.h
@@ -231,8 +231,19 @@ void ftpfs_dir_free (struct ftpfs_dir *dir);
/* Refresh DIR. */
error_t ftpfs_dir_refresh (struct ftpfs_dir *dir);
-/* Lookup NAME in DIR, returning its entry, or an error. */
+/* Lookup NAME in DIR, returning its entry, or an error. DIR's node should
+ be locked, and will be unlocked after returning; *NODE will contain the
+ result node, locked, and with an additional reference, or 0 if an error
+ occurs. */
error_t ftpfs_dir_lookup (struct ftpfs_dir *dir, const char *name,
struct node **node);
+/* Lookup the null name in DIR, and return a node for it in NODE. Unlike
+ ftpfs_dir_lookup, this won't attempt to validate the existance of the
+ entry (to avoid opening a new connection if possible) -- that will happen
+ the first time the entry is refreshed. Also unlink ftpfs_dir_lookup, this
+ function doesn't expect DIR to be locked, and won't return *NODE locked.
+ This function is only used for bootstrapping the root node. */
+error_t ftpfs_dir_null_lookup (struct ftpfs_dir *dir, struct node **node);
+
#endif /* __FTPFS_H__ */